==> haskell-base-compat-0.9.3-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-base-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-compat
version: 0.9.3
id: base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF
key: base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF
license: MIT
copyright: (c) 2012-2017 Simon Hengel,
           (c) 2014-2017 João Cristóvão,
           (c) 2015-2017 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
synopsis: A compatibility layer for base
description:
    Provides functions available in later versions of @base@ to
    a wider range of compilers, without requiring you to use CPP
    pragmas in your code.  See the
    <https://github.com/haskell-compat/base-compat#readme README>
    for what is covered. Also see the
    <https://github.com/haskell-compat/base-compat/blob/master/CHANGES.markdown changelog>
    for recent changes.
    .
    Note that @base-compat@ does not add any orphan instances.
    There is a separate package,
    @<http://hackage.haskell.org/package/base-orphans base-orphans>@,
    for that.
    .
    In addition, `base-compat` does not backport any data types
    or type classes. See
    @<https://github.com/haskell-compat/base-compat#data-types-and-type-classes this section of the README>@
    for more info.
category: Compatibility
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
exposed: True
exposed-modules:
    Control.Concurrent.Compat Control.Concurrent.MVar.Compat
    Control.Monad.Compat Control.Monad.ST.Lazy.Unsafe.Compat
    Control.Monad.ST.Unsafe.Compat Data.Bits.Compat Data.Bool.Compat
    Data.Complex.Compat Data.Either.Compat Data.Foldable.Compat
    Data.Function.Compat Data.Functor.Compat Data.Functor.Const.Compat
    Data.IORef.Compat Data.List.Compat Data.Monoid.Compat
    Data.Proxy.Compat Data.Ratio.Compat Data.STRef.Compat
    Data.String.Compat Data.Type.Coercion.Compat Data.Version.Compat
    Data.Word.Compat Debug.Trace.Compat Foreign.Compat
    Foreign.ForeignPtr.Compat Foreign.ForeignPtr.Safe.Compat
    Foreign.ForeignPtr.Unsafe.Compat Foreign.Marshal.Alloc.Compat
    Foreign.Marshal.Array.Compat Foreign.Marshal.Compat
    Foreign.Marshal.Safe.Compat Foreign.Marshal.Unsafe.Compat
    Foreign.Marshal.Utils.Compat Numeric.Compat Prelude.Compat
    System.Environment.Compat System.Exit.Compat
    System.IO.Unsafe.Compat Text.Read.Compat
abi: b2594bcf5f29380fe10c0f91686a5e2c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/base-compat-0.9.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/base-compat-0.9.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/base-compat-0.9.3
hs-libraries: HSbase-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF
depends:
    base-4.9.0.0 unix-2.7.2.0
haddock-interfaces: /usr/share/doc/haskell-base-compat/html/base-compat.haddock
haddock-html: /usr/share/doc/haskell-base-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-compat-0.9.3-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-base-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-compat
version: 0.9.3
id: base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
key: base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
license: MIT
copyright: (c) 2012-2017 Simon Hengel,
           (c) 2014-2017 João Cristóvão,
           (c) 2015-2017 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
synopsis: A compatibility layer for base
description:
    Provides functions available in later versions of @base@ to
    a wider range of compilers, without requiring you to use CPP
    pragmas in your code.  See the
    <https://github.com/haskell-compat/base-compat#readme README>
    for what is covered. Also see the
    <https://github.com/haskell-compat/base-compat/blob/master/CHANGES.markdown changelog>
    for recent changes.
    .
    Note that @base-compat@ does not add any orphan instances.
    There is a separate package,
    @<http://hackage.haskell.org/package/base-orphans base-orphans>@,
    for that.
    .
    In addition, `base-compat` does not backport any data types
    or type classes. See
    @<https://github.com/haskell-compat/base-compat#data-types-and-type-classes this section of the README>@
    for more info.
category: Compatibility
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
exposed: True
exposed-modules:
    Control.Concurrent.Compat Control.Concurrent.MVar.Compat
    Control.Monad.Compat Control.Monad.ST.Lazy.Unsafe.Compat
    Control.Monad.ST.Unsafe.Compat Data.Bits.Compat Data.Bool.Compat
    Data.Complex.Compat Data.Either.Compat Data.Foldable.Compat
    Data.Function.Compat Data.Functor.Compat Data.Functor.Const.Compat
    Data.IORef.Compat Data.List.Compat Data.Monoid.Compat
    Data.Proxy.Compat Data.Ratio.Compat Data.STRef.Compat
    Data.String.Compat Data.Type.Coercion.Compat Data.Version.Compat
    Data.Word.Compat Debug.Trace.Compat Foreign.Compat
    Foreign.ForeignPtr.Compat Foreign.ForeignPtr.Safe.Compat
    Foreign.ForeignPtr.Unsafe.Compat Foreign.Marshal.Alloc.Compat
    Foreign.Marshal.Array.Compat Foreign.Marshal.Compat
    Foreign.Marshal.Safe.Compat Foreign.Marshal.Unsafe.Compat
    Foreign.Marshal.Utils.Compat Numeric.Compat Prelude.Compat
    System.Environment.Compat System.Exit.Compat
    System.IO.Unsafe.Compat Text.Read.Compat
abi: 4e38560398f1df4c61d8e909a556d24b
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/base-compat-0.9.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/base-compat-0.9.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/base-compat-0.9.3
hs-libraries: HSbase-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
depends:
    base-4.9.1.0 unix-2.7.2.1
haddock-interfaces: /usr/share/doc/haskell-base-compat/html/base-compat.haddock
haddock-html: /usr/share/doc/haskell-base-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
